@@ -3,7 +3,7 @@
 from IPython import get_ipython
 from IPython.core.magic import cell_magic
 from IPython.core.magic_arguments import argument, magic_arguments, parse_argstring
-from IPython.display import display, HTML
+from IPython.display import display
 
 from genai.components import completion_made, starting_message
 from genai.context import get_historical_context
@@ -68,7 +68,7 @@ def assist(line, cell):
     # how can I query for pokemon via the PokéAPI?
     ```
     """
-    progress = display(HTML(starting_message()), display_id=True)
+    progress = display(starting_message(), display_id=True)
 
     args = parse_argstring(assist, line)
 
@@ -86,12 +86,17 @@ def assist(line, cell):
 
     generated_text = generate_next_cell(context, cell_text)
 
-    progress.update(HTML(completion_made()))
+    progress.update(completion_made())
 
-    new_cell = f"""{cell_text}\n{generated_text}"""
+    new_cell = generated_text
 
     if args.in_place:
-        new_cell = f"""#%%assist {line}\n{cell_text}\n{generated_text}"""
+        # Since we're running it in place, keep the context of what was sent in.
+        # The preamble is a comment with the magic line and the original cell text all commented out
+        processed_cell_text = "\n".join(f"# {line}" for line in cell_text.splitlines())
+        preamble = f"""#%%assist {line}\n{processed_cell_text}"""
+
+        new_cell = f"""{preamble}\n{generated_text}"""
 
     ip.set_next_input(
         new_cell,
